<?php
/**
 * Fichier gérant l'installation et désinstallation du plugin Cartes.
 *
 * @plugin     Cartes
 *
 * @copyright  2021
 * @author     Eric Lupinacci
 *
 * @licence    GNU/GPL
 *
 * @package    SPIP\Cartes\Installation
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Fonction d'installation et de mise à jour du plugin Cartes.
 *
 * @param string $nom_meta_base_version
 *                                      Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 * @param string $version_cible
 *                                      Version du schéma de données dans ce plugin (déclaré dans paquet.xml)
 *
 * @return void
**/
function cartes_territoires_upgrade($nom_meta_base_version, $version_cible) {
	$maj = [];

	$maj['create'] = [
		['maj_tables', ['spip_cartes_territoires', 'spip_cartes_territoires_liens']],
		['cartes_territoires_configurer']
	];

	include_spip('base/upgrade');
	maj_plugin($nom_meta_base_version, $version_cible, $maj);
}

/**
 * Fonction de désinstallation du plugin Cartes.
 *
 * @param string $nom_meta_base_version
 *                                      Nom de la meta informant de la version du schéma de données du plugin installé dans SPIP
 *
 * @return void
**/
function cartes_territoires_vider_tables($nom_meta_base_version) {
	// Supprimer les tables ajoutées par le plugin
	sql_drop_table('spip_cartes_territoires');
	sql_drop_table('spip_cartes_territoires_liens');

	// Nettoyer les liens courants (le génie optimiser_base_disparus se chargera de nettoyer toutes les tables de liens)
	sql_delete('spip_documents_liens', sql_in('objet', ['carte']));
	sql_delete('spip_mots_liens', sql_in('objet', ['carte']));
	sql_delete('spip_auteurs_liens', sql_in('objet', ['carte']));
	// Nettoyer les versionnages et forums
	sql_delete('spip_versions', sql_in('objet', ['carte']));
	sql_delete('spip_versions_fragments', sql_in('objet', ['carte']));
	sql_delete('spip_forum', sql_in('objet', ['carte']));

	// Effacer les meta du plugin
	// - la meta de configuration technique du plugin
	effacer_meta('cartes_territoires');
	// - la meta de schéma
	effacer_meta($nom_meta_base_version);
}

function cartes_territoires_configurer() {
	// Initialisation de la configuration
	// -- Configuration statique du plugin
	$config_statique = [
		'filtres' => [
			'profondeur' => [
				'types_compatibles' => ['subdivision'],
				'champ_id'          => 'profondeur_type',
				'champ_nom'         => '',
				'variable_liste'    => '_profondeurs',
				'variable_choix'    => 'profondeurs'
			],
			'parent' => [
				'types_compatibles' => ['country'],
				'champ_id'          => 'iso_parent',
				'champ_nom'         => 'nom_usage',
				'variable_liste'    => '_parents',
				'variable_choix'    => 'parents'
			],
			'categorie' => [
				'types_compatibles' => ['zone', 'subdivision', 'protected_area', 'infrasubdivision'],
				'champ_id'          => 'categorie',
				'champ_nom'         => '',
				'variable_liste'    => '_categories',
				'variable_choix'    => 'categories'
			],
		],
	];

	// Ecriture de la meta associée
	ecrire_config('cartes_territoires', $config_statique);
}
